@@ -1,14 +1,13 @@
-from typing import List
+from __future__ import annotations
 
 from soda.profiling.discover_tables_result_column import DiscoverTablesResultColumn
 
 
 class DiscoverTablesResultTable:
-    def __init__(self, table_name: str, data_source: str, row_count: int):
+    def __init__(self, table_name: str, data_source: str):
         self.table_name: str = table_name
         self.data_source: str = data_source
-        self.row_count: int = row_count
-        self.result_columns: List[DiscoverTablesResultColumn] = []
+        self.result_columns: list[DiscoverTablesResultColumn] = []
 
     def create_column(self, column_name: str, column_type: str) -> DiscoverTablesResultColumn:
         column = DiscoverTablesResultColumn(column_name, column_type)
@@ -19,7 +18,6 @@ class DiscoverTablesResultTable:
         cloud_dict = {
             "table": self.table_name,
             "dataSource": self.data_source,
-            "rowCount": self.row_count,
             "schema": [result_column.get_cloud_dict() for result_column in self.result_columns],
         }
         return cloud_dict
@@ -28,6 +26,5 @@ class DiscoverTablesResultTable:
         return {
             "table": self.table_name,
             "dataSource": self.data_source,
-            "rowCount": self.row_count,
             "schema": [result_column.get_dict() for result_column in self.result_columns],
         }
