@@ -16,6 +16,7 @@ class DistributionCheckCfg(CheckCfg):
         column_name: str,
         distribution_name: str,
         filter: str,
+        sample_clause: str,
         reference_file_path: str,
         fail_threshold_cfg: ThresholdCfg | None,
         warn_threshold_cfg: ThresholdCfg | None,
@@ -31,6 +32,7 @@ class DistributionCheckCfg(CheckCfg):
         self.column_name = column_name
         self.distribution_name = distribution_name
         self.filter = filter
+        self.sample_clause = sample_clause
         self.reference_file_path = reference_file_path
         self.fail_threshold_cfg = fail_threshold_cfg
         self.warn_threshold_cfg = warn_threshold_cfg
